@@ -7,7 +7,7 @@ class Payload:
     """DataWeave payload.
     """
 
-    def __init__(self, payloadType: PayloadType, data: Union[str, bytes, BufferedIOBase]):
+    def __init__(self, payloadType: PayloadType, data: Union[dict, str, bytes, BufferedIOBase]):
         """Creates a new DataWeave payload instance.
 
         Args:
