@@ -13,7 +13,8 @@ from .Error import Error
 from .Payload import Payload
 
 def as_bytes(data) -> str:
-    """Converts the input into bytes. Input data should be a string, bytes, or a file-like object.
+    """Converts the input into bytes. Input data should be a string, bytes,
+    dict, list, or a file-like object.
 
     Args:
         data: input data
@@ -24,13 +25,16 @@ def as_bytes(data) -> str:
 
     str_data = None
 
-    #
+    
     if isinstance(data, str):
         str_data = data.encode("utf-8")
 
     elif isinstance(data, bytes):
         str_data = data
 
+    elif isinstance(data, dict) or isinstance(data, list):
+        str_data = json.dumps(data).encode("utf-8")
+
     else:
         read_f = getattr(data, "read", None)
         if callable(read_f):
@@ -58,11 +62,12 @@ def run(payload: Dict[str, Payload], script: Union[str, bytes, BufferedIOBase],
 
     # convert payloads to temp files
     for p in iter(payload):
-        with NamedTemporaryFile("wb", suffix=f"-.{payload[p].payloadType}", delete=False) as temp_file:
+        payload_id = re.sub(r"\W+", "_", p)
+        with NamedTemporaryFile("wb", suffix=f"-{payload_id}.{payload[p].payloadType}", delete=False) as temp_file:
             temp_file.write(as_bytes(payload[p].data))
             payload[p].data = temp_file.name
         args.append("--input")
-        args.append(p)
+        args.append(payload_id)
         args.append(payload[p].data)
 
     # convert script file to temp file
@@ -105,6 +110,10 @@ def run(payload: Dict[str, Payload], script: Union[str, bytes, BufferedIOBase],
                 stderr=result.stderr.decode("utf-8")
             )
 
+    # propagate DataWeave errors instead of wrapping
+    except Error as e:
+        raise e
+
     # catch any system-level errors
     except Exception as e:
         raise Error(
